package org.jeecg.modules.stm.rectify.plan.service;

import org.jeecg.modules.stm.rectify.plan.entity.StRectifyPlan;
import org.jeecg.modules.stm.rectify.plan.vo.StRectifyPlanVo;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * @Description: 整改计划
 * @Author: jeecg-boot
 * @Date:   2023-07-21
 * @Version: V1.0
 */
public interface IStRectifyPlanService extends IService<StRectifyPlan> {
	public IPage<StRectifyPlanVo> queryStRectifyPlanVoByPage(IPage<StRectifyPlanVo> page,StRectifyPlanVo stRectifyPlanVo);
	public void saveOrUpateStRectifyPlan(StRectifyPlan stRectifyPlan);
	public void saveOrUpateStRectifyExecute(StRectifyPlan stRectifyPlan);
	public void saveOrUpateStRectifyApprove(StRectifyPlan stRectifyPlan);
}
